@@ -3,8 +3,6 @@
 #
 # SPDX-License-Identifier: GPL-2.0-or-later
 
-from __future__ import division, print_function
-
 import binascii
 import copy
 import hashlib
@@ -554,7 +552,7 @@ class ESP32FirmwareImage(BaseFirmwareImage):
 
     IROM_ALIGN = 65536
 
-    def __init__(self, load_file=None):
+    def __init__(self, load_file=None, append_digest=True):
         super(ESP32FirmwareImage, self).__init__()
         self.secure_pad = None
         self.flash_mode = 0
@@ -568,9 +566,10 @@ class ESP32FirmwareImage(BaseFirmwareImage):
         self.cs_drv = 0
         self.hd_drv = 0
         self.wp_drv = 0
+        self.chip_id = 0
         self.min_rev = 0
 
-        self.append_digest = True
+        self.append_digest = append_digest
 
         if load_file is not None:
             start = load_file.tell()
@@ -771,16 +770,18 @@ class ESP32FirmwareImage(BaseFirmwareImage):
         self.d_drv, self.cs_drv = split_byte(fields[2])
         self.hd_drv, self.wp_drv = split_byte(fields[3])
 
-        chip_id = fields[4]
-        if chip_id != self.ROM_LOADER.IMAGE_CHIP_ID:
+        self.chip_id = fields[4]
+        if self.chip_id != self.ROM_LOADER.IMAGE_CHIP_ID:
             print(
                 (
                     "Unexpected chip id in image. Expected %d but value was %d. "
                     "Is this image for a different chip model?"
                 )
-                % (self.ROM_LOADER.IMAGE_CHIP_ID, chip_id)
+                % (self.ROM_LOADER.IMAGE_CHIP_ID, self.chip_id)
             )
 
+        self.min_rev = fields[5]
+
         # reserved fields in the middle should all be zero
         if any(f for f in fields[6:-1] if f != 0):
             print(
